Configuring the generated interface
-----------------------------------


The "Relation tags" structure
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: `cubicweb.rtags`
   :members:


The `uicfg` module (:mod:`cubicweb.web.uicfg`)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: `cubicweb.web.uicfg`
   :members:
